@@ -9,6 +9,7 @@ import json
 import pygsheets
 import requests
 import googleapiclient
+import yaml
 from googleauthentication import GoogleAuthentication
 from dbstream import DBStream
 
@@ -136,10 +137,11 @@ class Spreadsheet:
                 result.append(column_name)
         return result
 
-    def get_info_from_worksheets(self, config, fr_to_us_date=False, avoid_lines=None,
+    def get_info_from_worksheets(self, config_path, fr_to_us_date=False, avoid_lines=None,
                                  transform_comma=False,
                                  format_date_from=None, list_col_to_remove=None, special_table_name=None,
                                  remove_comma=False, treat_int_column=False, remove_comma_float=False):
+        config = yaml.load(open(config_path), Loader=yaml.FullLoader)
         for key in config:
             worksheet_name = config[key]['worksheet_name']
             wks = self._get_worksheets_by_id(config[key]['sheet_id'], worksheet_name)
